@@ -14,7 +14,7 @@
  
  
  Peter Beerli 1996-1998, Seattle
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
  
     Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
@@ -25,7 +25,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: combroyden2.c 1189 2008-03-10 19:58:39Z beerli $
+$Id: combroyden2.c 1323 2008-07-25 19:13:48Z beerli $
  
 -------------------------------------------------------*/
 
