@@ -12,7 +12,7 @@
  destroys data.
  
  Peter Beerli 1996, Seattle
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2007 Peter Beerli, Tallahassee FL
@@ -22,7 +22,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: data.c 1314 2008-07-05 13:47:13Z beerli $
+$Id: data.c 1323 2008-07-25 19:13:48Z beerli $
  
 -------------------------------------------------------*/
 /*! \file data.c
