@@ -9,7 +9,7 @@
   School of Computational Science and Biological Sciences
   Florida State University
   Tallahassee, FL 32306-4120
-  beerli@scs.fsu.edu
+  beerli@fsu.edu
  
   With help of Joe Felsenstein (joe@genetics.washington.edu),
   Mary Kuhner and Jon Yamato (mkkuhner@genetics.washington.edu)
@@ -17,23 +17,23 @@
   
 Copyright 2002 Peter Beerli and Joseph Felsenstein
  
-$Id: definitions.h 1296 2008-06-12 21:06:42Z beerli $
+$Id: definitions.h 1323 2008-07-25 19:13:48Z beerli $
  
   *----------------------------------------------------------------
   */
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "2.5.1"
+#define MIGRATEVERSION "3.0"
 #else
 #ifdef SGI
 #undef MIGRATEVERSION
-#define MIGRATEVERSION "2.5.1"
+#define MIGRATEVERSION "3.0"
 #endif
 #endif
 #ifndef MIGRATESUBVERSION
 #define MIGRATESUBVERSION "x"
 #endif
 
-#define MAINTAINER "Peter Beerli <beerli@scs.fsu.edu>"
+#define MAINTAINER "Peter Beerli <beerli@fsu.edu>"
 /*------------------------------------------------
   Adjusting the source to the system configuration
 */
