@@ -8,7 +8,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
  calculates FST
  
  Peter Beerli 1996, Seattle
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
  Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
@@ -18,7 +18,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: fst.c 633 2007-03-06 04:14:07Z beerli $
+$Id: fst.c 1323 2008-07-25 19:13:48Z beerli $
  
 -------------------------------------------------------*/
 /*! \file fst.c
