@@ -6,7 +6,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
  Gammalike and derivatives  R O U T I N E S
  
  Peter Beerli 2001, Seattle
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
  Copyright 2001-2003 Peter Beerli and Joseph Felsenstein
  Copyright 2004-2005 Peter Beerli
@@ -15,7 +15,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: gammalike.c 886 2007-08-18 03:09:50Z beerli $
+$Id: gammalike.c 1323 2008-07-25 19:13:48Z beerli $
 */
 /*! \file gammalike.c 
 
