@@ -5,13 +5,13 @@ part of migrate
 Peter Beerli 2000
  
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
-Copyright 2003-2004 Peter Beerli, Tallahassee FL
+Copyright 2003-2008 Peter Beerli, Tallahassee FL
  
 This software is distributed free of charge for non-commercial use
 and is copyrighted. Of course, we do not guarantee that the software
 works and are not responsible for any damage you may cause or have.
  
-$Id: heating.c 655 2007-03-28 02:31:53Z beerli $
+$Id: heating.c 1049 2007-11-29 22:47:41Z beerli $
  
 */
 /*! \file heating.c 
@@ -37,9 +37,12 @@ void thread_tree_update (void *thisworld);
 int tpool_destroy (tpool_t tpool, int finish);
 void tpool_thread (tpool_t tpool);
 int tpool_synchronize (tpool_t tpool, int finish);
+void allocate_thread_workp(long n, tpool_work_t ** workpointers);
 
 extern void run_one_update(world_fmt *world); //defined in main.c
 
+tpool_work_t **thread_work_pointers;
+
 void
 tpool_init (tpool_t * tpoolp, int num_worker_threads, int max_queue_size,
             int do_not_block_when_full)
@@ -82,10 +85,21 @@ tpool_init (tpool_t * tpoolp, int num_worker_threads, int max_queue_size,
             error ("Thread pool creation failed with pthread_create");
     }
     *tpoolp = tpool;
+    thread_work_pointers = (tpool_work_t **) mycalloc(num_worker_threads, sizeof(tpool_work_t *));
+    allocate_thread_workp(num_worker_threads, thread_work_pointers);
+}
+
+
+void allocate_thread_workp(long n, tpool_work_t ** workpointers)
+{
+    // memory savings?
+  long i;
+  for(i=0;i<n;i++)
+    (workpointers)[i] = (tpool_work_t *) mymalloc (sizeof (tpool_work_t));
 }
 
 int
-tpool_add_work (tpool_t tpool, void *routine, void *arg)
+tpool_add_work (tpool_t tpool, void *routine, void *arg, long z)
 {
     tpool_work_t *workp;
     pthread_mutex_lock (&tpool->queue_lock);
@@ -108,7 +122,8 @@ tpool_add_work (tpool_t tpool, void *routine, void *arg)
         return -1;
     }
 
-    workp = (tpool_work_t *) mymalloc (sizeof (tpool_work_t));
+    //    workp = (tpool_work_t *) mymalloc (sizeof (tpool_work_t));
+    workp = thread_work_pointers[z];
     workp->routine = routine;
     workp->arg = arg;
     workp->next = NULL;
@@ -137,7 +152,7 @@ void fill_tpool (tpool_t tpool, world_fmt ** universe, int universe_size)
     int i;
     for (i = 0; i < universe_size; i++)
     {
-        if (!tpool_add_work (tpool, thread_tree_update, (void *) universe[i]))
+      if (!tpool_add_work (tpool, thread_tree_update, (void *) universe[i], i))
             error ("Filling heating queue failed");
     }
 }
