@@ -16,7 +16,7 @@
 *
 *  \section maintainer Maintainer and Copyrights 
 *   Peter Beerli,
-*   beerli@scs.fsu.edu
+*   beerli@fsu.edu
 *
 *   Copyright 1997-2002 Peter Beerli and Joseph Felsenstein, Seattle WA\n
 *   Copyright 2003-2008 Peter Beerli, Tallahassee FL\n
@@ -26,7 +26,7 @@
 *   works and am not responsible for any damage you may cause or have.
 *
 */
-/* $Id: main.c 1309 2008-06-29 18:01:37Z beerli $*/
+/* $Id: main.c 1331 2008-07-31 18:55:29Z beerli $*/
 
 #include "migration.h"
 #include "sighandler.h"
@@ -892,7 +892,7 @@ run_sampler (option_fmt * options, data_fmt * data, world_fmt ** universe,
     istatus = (MPI_Status *) mycalloc (minnodes + 1, sizeof (MPI_Status));
     if (myID == MASTER)
     {
-        mpi_runloci_master (data->loci, EARTH->who, EARTH, options->readsum);
+      mpi_runloci_master (data->loci, EARTH->who, EARTH, options->readsum, options->menu);
 #ifndef MPIREPLICANT
         sent = mpi_send_stop_mcmc_worker (numcpu, data->loci, &comm_world, irequests,istatus, myID);
 
@@ -1292,7 +1292,7 @@ analyze_olddata (world_fmt * world,
 #ifdef MPI
 	MYMPIBARRIER(comm_world);
 	printf("%i> before mpi_runlocimaster\n",myID);fflush(stdout);
-	mpi_runloci_master (world->loci, world->who, world, options->readsum);
+	mpi_runloci_master (world->loci, world->who, world, options->readsum, options->menu);
 	
 #else
         
