@@ -9,7 +9,7 @@
  
  
  Peter Beerli 1996, Seattle
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2006 Peter Beerli, Tallahassee FL
@@ -18,7 +18,7 @@ Copyright 2003-2006 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: mcmc1.c 1291 2008-06-11 16:04:14Z beerli $
+$Id: mcmc1.c 1323 2008-07-25 19:13:48Z beerli $
 -------------------------------------------------------*/
 /* \file mcmc1.c
 
