@@ -9,7 +9,7 @@
  
  
  Peter Beerli 1996, Seattle
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
@@ -18,7 +18,7 @@ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  and is copyrighted. Of course, we do not guarantee that the software
  works and are not responsible for any damage you may cause or have.
  
-$Id: mcmc2.c 1156 2008-02-14 18:30:18Z beerli $
+$Id: mcmc2.c 1323 2008-07-25 19:13:48Z beerli $
 -------------------------------------------------------*/
 /* \file mcmc2.c
 Contains low-level routines to manipulate the treechanger
