@@ -13,12 +13,12 @@
  
  
  Peter Beerli 1996, Seattle
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
  
-$Id: mcmc2.h 514 2006-11-09 20:14:08Z beerli $
+$Id: mcmc2.h 1323 2008-07-25 19:13:48Z beerli $
 -------------------------------------------------------*/
 
 extern void coalesce1p (proposal_fmt * proposal);
