@@ -12,11 +12,11 @@
   Department of Biological Sciences
   Florida State University
   Tallahassee FL 32306-4120
-  beerli@scs.fsu.edu
+  beerli@fsu.edu
  
   Copyright 2002 Peter Beerli and Joseph Felsenstein, Seattle WA
   Copyright 2003 Peter Beerli, Tallahassee FL
-  $Id: migration.h 1318 2008-07-10 19:49:13Z beerli $
+  $Id: migration.h 1323 2008-07-25 19:13:48Z beerli $
   *----------------------------------------------------------------
 */
 /**
