@@ -7,7 +7,7 @@
  
  
  Peter Beerli 1996, Seattle
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
  Copyright 2002 Peter Beerli and Joseph Felsenstein
  
@@ -16,7 +16,7 @@
  works and are not responsible for any damage you may cause or have.
  
  
- $Id: sequence.c 1314 2008-07-05 13:47:13Z beerli $
+ $Id: sequence.c 1323 2008-07-25 19:13:48Z beerli $
  
 -------------------------------------------------------*/
 /* \file sequence.c
