@@ -10,7 +10,7 @@
  
  
  Peter Beerli started 1996, Seattle
- beerli@scs.fsu.edu
+ beerli@fsu.edu
  
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2006 Peter Beerli, Tallahassee FL
@@ -20,7 +20,7 @@ Copyright 2003-2006 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: tools.c 1243 2008-05-10 18:07:45Z beerli $
+$Id: tools.c 1331 2008-07-31 18:55:29Z beerli $
 -------------------------------------------------------*/
 /* \file tools.c */
 
@@ -509,7 +509,9 @@ void collect_nodelet(world_fmt *world, node *p)
 	}
 #endif
       world->node_collection_count++;
+#ifdef DEBUG
       FPRINTF(stdout, "%i> Heat=%f: Collect_nodelet: recycler increased size to: %li/%li\n", myID, 1./world->heat, world->node_collection_count, world->node_collection_allocated);
+#endif
     }
   //printf("\n");
 }
